@@ -12,11 +12,11 @@ pub(crate) struct Ast<'src> {
 }
 
 impl<'src> Display for Ast<'src> {
-  fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
+  fn fmt(&self, f: &mut Formatter) -> fmt::Result {
     let mut iter = self.items.iter().peekable();
 
     while let Some(item) = iter.next() {
-      writeln!(f, "{}", item)?;
+      writeln!(f, "{item}")?;
 
       if let Some(next_item) = iter.peek() {
         if matches!(item, Item::Recipe(_))
