@@ -11,6 +11,7 @@ use super::*;
 pub(crate) enum Attribute<'src> {
   Confirm(Option<StringLiteral<'src>>),
   Doc(Option<StringLiteral<'src>>),
+  Extension(StringLiteral<'src>),
   Group(StringLiteral<'src>),
   Linux,
   Macos,
@@ -19,6 +20,7 @@ pub(crate) enum Attribute<'src> {
   NoQuiet,
   PositionalArguments,
   Private,
+  Script(Vec<StringLiteral<'src>>),
   Unix,
   Windows,
 }
@@ -27,7 +29,7 @@ impl AttributeDiscriminant {
   fn argument_range(self) -> RangeInclusive<usize> {
     match self {
       Self::Confirm | Self::Doc => 0..=1,
-      Self::Group => 1..=1,
+      Self::Group | Self::Extension => 1..=1,
       Self::Linux
       | Self::Macos
       | Self::NoCd
@@ -37,6 +39,7 @@ impl AttributeDiscriminant {
       | Self::Private
       | Self::Unix
       | Self::Windows => 0..=0,
+      Self::Script => 1..=usize::MAX,
     }
   }
 }
@@ -44,10 +47,8 @@ impl AttributeDiscriminant {
 impl<'src> Attribute<'src> {
   pub(crate) fn new(
     name: Name<'src>,
-    argument: Option<StringLiteral<'src>>,
+    arguments: Vec<StringLiteral<'src>>,
   ) -> CompileResult<'src, Self> {
-    use AttributeDiscriminant::*;
-
     let discriminant = name
       .lexeme()
       .parse::<AttributeDiscriminant>()
@@ -58,7 +59,7 @@ impl<'src> Attribute<'src> {
         })
       })?;
 
-    let found = argument.as_ref().iter().count();
+    let found = arguments.len();
     let range = discriminant.argument_range();
     if !range.contains(&found) {
       return Err(
@@ -72,18 +73,20 @@ impl<'src> Attribute<'src> {
     }
 
     Ok(match discriminant {
-      Confirm => Self::Confirm(argument),
-      Doc => Self::Doc(argument),
-      Group => Self::Group(argument.unwrap()),
-      Linux => Self::Linux,
-      Macos => Self::Macos,
-      NoCd => Self::NoCd,
-      NoExitMessage => Self::NoExitMessage,
-      NoQuiet => Self::NoQuiet,
-      PositionalArguments => Self::PositionalArguments,
-      Private => Self::Private,
-      Unix => Self::Unix,
-      Windows => Self::Windows,
+      AttributeDiscriminant::Confirm => Self::Confirm(arguments.into_iter().next()),
+      AttributeDiscriminant::Doc => Self::Doc(arguments.into_iter().next()),
+      AttributeDiscriminant::Extension => Self::Extension(arguments.into_iter().next().unwrap()),
+      AttributeDiscriminant::Group => Self::Group(arguments.into_iter().next().unwrap()),
+      AttributeDiscriminant::Linux => Self::Linux,
+      AttributeDiscriminant::Macos => Self::Macos,
+      AttributeDiscriminant::NoCd => Self::NoCd,
+      AttributeDiscriminant::NoExitMessage => Self::NoExitMessage,
+      AttributeDiscriminant::NoQuiet => Self::NoQuiet,
+      AttributeDiscriminant::PositionalArguments => Self::PositionalArguments,
+      AttributeDiscriminant::Private => Self::Private,
+      AttributeDiscriminant::Script => Self::Script(arguments),
+      AttributeDiscriminant::Unix => Self::Unix,
+      AttributeDiscriminant::Windows => Self::Windows,
     })
   }
 
@@ -91,12 +94,16 @@ impl<'src> Attribute<'src> {
     self.into()
   }
 
-  fn argument(&self) -> Option<&StringLiteral> {
+  fn arguments(&self) -> &[StringLiteral] {
     match self {
-      Self::Confirm(prompt) => prompt.as_ref(),
-      Self::Doc(doc) => doc.as_ref(),
-      Self::Group(group) => Some(group),
-      Self::Linux
+      Self::Confirm(Some(argument))
+      | Self::Doc(Some(argument))
+      | Self::Extension(argument)
+      | Self::Group(argument) => slice::from_ref(argument),
+      Self::Script(arguments) => arguments,
+      Self::Confirm(None)
+      | Self::Doc(None)
+      | Self::Linux
       | Self::Macos
       | Self::NoCd
       | Self::NoExitMessage
@@ -104,16 +111,29 @@ impl<'src> Attribute<'src> {
       | Self::PositionalArguments
       | Self::Private
       | Self::Unix
-      | Self::Windows => None,
+      | Self::Windows => &[],
     }
   }
 }
 
 impl<'src> Display for Attribute<'src> {
-  fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
+  fn fmt(&self, f: &mut Formatter) -> fmt::Result {
     write!(f, "{}", self.name())?;
-    if let Some(argument) = self.argument() {
-      write!(f, "({argument})")?;
+
+    let arguments = self.arguments();
+
+    for (i, argument) in arguments.iter().enumerate() {
+      if i == 0 {
+        write!(f, "(")?;
+      } else {
+        write!(f, ", ")?;
+      }
+
+      write!(f, "{argument}")?;
+
+      if i + 1 == arguments.len() {
+        write!(f, ")")?;
+      }
     }
 
     Ok(())
