@@ -42,11 +42,7 @@ pub(crate) enum Subcommand {
 }
 
 impl Subcommand {
-  pub(crate) fn execute<'src>(
-    &self,
-    config: &Config,
-    loader: &'src Loader,
-  ) -> Result<(), Error<'src>> {
+  pub(crate) fn execute<'src>(&self, config: &Config, loader: &'src Loader) -> RunResult<'src> {
     use Subcommand::*;
 
     match self {
@@ -83,7 +79,7 @@ impl Subcommand {
         justfile.run(config, &search, overrides, &[])?;
       }
       Dump => Self::dump(config, ast, justfile)?,
-      Format => Self::format(config, &search, src, ast)?,
+      Format => Self::format(config, &search, src, ast, justfile)?,
       Groups => Self::groups(config, justfile),
       List { path } => Self::list(config, justfile, path)?,
       Show { path } => Self::show(config, justfile, path)?,
@@ -97,7 +93,7 @@ impl Subcommand {
 
   fn groups(config: &Config, justfile: &Justfile) {
     println!("Recipe groups:");
-    for group in justfile.public_groups() {
+    for group in justfile.public_groups(config) {
       println!("{}{group}", config.list_prefix);
     }
   }
@@ -107,16 +103,17 @@ impl Subcommand {
     loader: &'src Loader,
     arguments: &[String],
     overrides: &BTreeMap<String, String>,
-  ) -> Result<(), Error<'src>> {
+  ) -> RunResult<'src> {
     if matches!(
       config.search_config,
       SearchConfig::FromInvocationDirectory | SearchConfig::FromSearchDirectory { .. }
     ) {
       let starting_path = match &config.search_config {
         SearchConfig::FromInvocationDirectory => config.invocation_directory.clone(),
-        SearchConfig::FromSearchDirectory { search_directory } => {
-          env::current_dir().unwrap().join(search_directory)
-        }
+        SearchConfig::FromSearchDirectory { search_directory } => config
+          .invocation_directory
+          .join(search_directory)
+          .lexiclean(),
         _ => unreachable!(),
       };
 
@@ -192,8 +189,10 @@ impl Subcommand {
     config: &Config,
     loader: &'src Loader,
     search: &Search,
-  ) -> Result<Compilation<'src>, Error<'src>> {
-    let compilation = Compiler::compile(config.unstable, loader, &search.justfile)?;
+  ) -> RunResult<'src, Compilation<'src>> {
+    let compilation = Compiler::compile(loader, &search.justfile)?;
+
+    compilation.justfile.check_unstable(config)?;
 
     if config.verbosity.loud() {
       for warning in &compilation.justfile.warnings {
@@ -214,8 +213,8 @@ impl Subcommand {
     search: &Search,
     overrides: &BTreeMap<String, String>,
     chooser: Option<&str>,
-  ) -> Result<(), Error<'src>> {
-    let mut recipes = Vec::<&Recipe<Dependency>>::new();
+  ) -> RunResult<'src> {
+    let mut recipes = Vec::<&Recipe>::new();
     let mut stack = vec![justfile];
     while let Some(module) = stack.pop() {
       recipes.extend(
@@ -304,7 +303,7 @@ impl Subcommand {
     Ok(())
   }
 
-  fn dump(config: &Config, ast: &Ast, justfile: &Justfile) -> Result<(), Error<'static>> {
+  fn dump(config: &Config, ast: &Ast, justfile: &Justfile) -> RunResult<'static> {
     match config.dump_format {
       DumpFormat::Json => {
         serde_json::to_writer(io::stdout(), justfile)
@@ -316,7 +315,7 @@ impl Subcommand {
     Ok(())
   }
 
-  fn edit(search: &Search) -> Result<(), Error<'static>> {
+  fn edit(search: &Search) -> RunResult<'static> {
     let editor = env::var_os("VISUAL")
       .or_else(|| env::var_os("EDITOR"))
       .unwrap_or_else(|| "vim".into());
@@ -338,8 +337,14 @@ impl Subcommand {
     Ok(())
   }
 
-  fn format(config: &Config, search: &Search, src: &str, ast: &Ast) -> Result<(), Error<'static>> {
-    config.require_unstable("The `--fmt` command is currently unstable.")?;
+  fn format(
+    config: &Config,
+    search: &Search,
+    src: &str,
+    ast: &Ast,
+    justfile: &Justfile,
+  ) -> RunResult<'static> {
+    config.require_unstable(justfile, UnstableFeature::FormatSubcommand)?;
 
     let formatted = ast.to_string();
 
@@ -383,7 +388,7 @@ impl Subcommand {
     Ok(())
   }
 
-  fn init(config: &Config) -> Result<(), Error<'static>> {
+  fn init(config: &Config) -> RunResult<'static> {
     let search = Search::init(&config.search_config, &config.invocation_directory)?;
 
     if search.justfile.is_file() {
@@ -403,7 +408,7 @@ impl Subcommand {
     }
   }
 
-  fn man() -> Result<(), Error<'static>> {
+  fn man() -> RunResult<'static> {
     let mut buffer = Vec::<u8>::new();
 
     Man::new(Config::app())
@@ -423,7 +428,7 @@ impl Subcommand {
     Ok(())
   }
 
-  fn list(config: &Config, mut module: &Justfile, path: &ModulePath) -> Result<(), Error<'static>> {
+  fn list(config: &Config, mut module: &Justfile, path: &ModulePath) -> RunResult<'static> {
     for name in &path.path {
       module = module
         .modules
@@ -439,6 +444,27 @@ impl Subcommand {
   }
 
   fn list_module(config: &Config, module: &Justfile, depth: usize) {
+    fn format_doc(
+      config: &Config,
+      name: &str,
+      doc: Option<&str>,
+      max_signature_width: usize,
+      signature_widths: &BTreeMap<&str, usize>,
+    ) {
+      if let Some(doc) = doc {
+        if !doc.is_empty() && doc.lines().count() <= 1 {
+          print!(
+            "{:padding$}{} {}",
+            "",
+            config.color.stdout().doc().paint("#"),
+            config.color.stdout().doc().paint(doc),
+            padding = max_signature_width.saturating_sub(signature_widths[name]) + 1,
+          );
+        }
+      }
+      println!();
+    }
+
     let aliases = if config.no_aliases {
       BTreeMap::new()
     } else {
@@ -472,6 +498,11 @@ impl Subcommand {
           );
         }
       }
+      if !config.list_submodules {
+        for (name, _) in &module.modules {
+          signature_widths.insert(name, UnicodeWidthStr::width(format!("{name} ...").as_str()));
+        }
+      }
 
       signature_widths
     };
@@ -504,23 +535,33 @@ impl Subcommand {
       groups
     };
 
-    for (i, (group, recipes)) in groups.iter().enumerate() {
+    let mut ordered = module
+      .public_groups(config)
+      .into_iter()
+      .map(Some)
+      .collect::<Vec<Option<String>>>();
+
+    if groups.contains_key(&None) {
+      ordered.insert(0, None);
+    }
+
+    let no_groups = groups.contains_key(&None) && groups.len() == 1;
+
+    for (i, group) in ordered.into_iter().enumerate() {
       if i > 0 {
         println!();
       }
 
-      let no_groups = groups.contains_key(&None) && groups.len() == 1;
-
       if !no_groups {
         print!("{list_prefix}");
-        if let Some(group_name) = group {
-          println!("[{group_name}]");
+        if let Some(group) = &group {
+          println!("[{group}]");
         } else {
           println!("(no group)");
         }
       }
 
-      for recipe in recipes {
+      for recipe in groups.get(&group).unwrap() {
         for (i, name) in iter::once(&recipe.name())
           .chain(aliases.get(recipe.name()).unwrap_or(&Vec::new()))
           .enumerate()
@@ -548,18 +589,13 @@ impl Subcommand {
             RecipeSignature { name, recipe }.color_display(config.color.stdout())
           );
 
-          if let Some(doc) = doc {
-            if doc.lines().count() <= 1 {
-              print!(
-                "{:padding$}{} {}",
-                "",
-                config.color.stdout().doc().paint("#"),
-                config.color.stdout().doc().paint(&doc),
-                padding = max_signature_width.saturating_sub(signature_widths[name]) + 1,
-              );
-            }
-          }
-          println!();
+          format_doc(
+            config,
+            name,
+            doc.as_deref(),
+            max_signature_width,
+            &signature_widths,
+          );
         }
       }
     }
@@ -575,8 +611,19 @@ impl Subcommand {
         Self::list_module(config, submodule, depth + 1);
       }
     } else {
-      for submodule in module.modules(config) {
-        println!("{list_prefix}{} ...", submodule.name(),);
+      for (i, submodule) in module.modules(config).into_iter().enumerate() {
+        if !no_groups && !groups.is_empty() && i == 0 {
+          println!();
+        }
+
+        print!("{list_prefix}{} ...", submodule.name());
+        format_doc(
+          config,
+          submodule.name(),
+          submodule.doc.as_deref(),
+          max_signature_width,
+          &signature_widths,
+        );
       }
     }
   }
@@ -585,7 +632,7 @@ impl Subcommand {
     config: &Config,
     mut module: &Justfile<'src>,
     path: &ModulePath,
-  ) -> Result<(), Error<'src>> {
+  ) -> RunResult<'src> {
     for name in &path.path[0..path.path.len() - 1] {
       module = module
         .modules
